@@ -1,16 +1,16 @@
 #############################################################
 #                                                           #
-#	wle.cv.one function                                     #
-#	Author: Claudio Agostinelli                             #
-#	E-mail: claudio@unive.it                                #
-#	Date: December, 29, 2003                                #
-#	Version: 0.1-2                                          #
+#	wle.cv.one function                                 #
+#	Author: Claudio Agostinelli                         #
+#	E-mail: claudio@unive.it                            #
+#	Date: October, 13, 2012                             #
+#	Version: 0.1-3                                      #
 #                                                           #
-#	Copyright (C) 2003 Claudio Agostinelli                  #
+#	Copyright (C) 2012 Claudio Agostinelli              #
 #                                                           #
 #############################################################
 
-wle.cv.one <- function(formula, data=list(), model=TRUE, x=FALSE, y=FALSE, monte.carlo=500, split, boot=30, group, num.sol=1, raf="HD", smooth=0.031, tol=10^(-6), equal=10^(-3), max.iter=500, min.weight=0.5, contrasts=NULL, num.max, nmodel, verbose=FALSE, seed=1234, file, append=FALSE, ...) {
+wle.cv.one <- function(formula, data=list(), model=TRUE, x=FALSE, y=FALSE, monte.carlo=500, split, boot=30, group, num.sol=1, raf="HD", smooth=0.031, tol=10^(-6), equal=10^(-3), max.iter=500, min.weight=0.5, contrasts=NULL, num.max, nmodel, verbose=FALSE, file, append=FALSE, ...) {
 
 raf <- switch(raf,
 	HD = 1,
@@ -46,7 +46,7 @@ if (!missing(file)) {
     mf$contrasts <- NULL
     mf$model <- mf$x <- mf$y <- NULL
     mf$verbose <- NULL
-    mf$num.max <- mf$nmodel <- mf$seed <- mf$file <- mf$... <- NULL
+    mf$num.max <- mf$nmodel <- mf$file <- mf$... <- NULL
     mf$drop.unused.levels <- TRUE
     mf[[1]] <- as.name("model.frame")
     mf <- eval(mf, sys.frame(sys.parent()))
@@ -198,7 +198,6 @@ for (imodel in nmodel) {
 	as.integer(monte.carlo),
         as.integer(imodel),
 	as.integer(split),
-        as.integer(seed),
         as.double(dpesi),
 	wcv=double(nvar+1),
 	info=integer(1),
