@@ -149,7 +149,7 @@ wle.t.test <- function(x, y=NULL, alternative = c("two.sided", "less", "greater"
 	cint <- c(NA, tstat + qt(conf.level, df) )
     }
     else if (alternative == "greater") {
-	pval <- pt(tstat, df, lower = FALSE)
+	pval <- pt(tstat, df, lower.tail = FALSE)
 	cint <- c(tstat - qt(conf.level, df), NA)
     }
     else {
